FunctionCall class
A predicted function call returned from the model.
Constructors
-
FunctionCall({String? id, required String name, Map<
String, dynamic> ? args}) -
Creates a FunctionCall.
const
-
FunctionCall.fromJson(Map<
String, dynamic> json) -
Creates a FunctionCall from JSON.
factory
Properties
-
args
→ Map<
String, dynamic> ? -
The function parameters and values.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
Optional unique ID of the function call for correlation.
final
- name → String
-
The name of the function to call.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? id = unsetCopyWithValue, Object? name = unsetCopyWithValue, Object? args = unsetCopyWithValue}) → FunctionCall - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited