id property
Optional unique ID of the function call for correlation.
Used in Live API sessions to match tool call responses to requests and to identify calls in cancellation messages.
Implementation
final String? id;
Optional unique ID of the function call for correlation.
Used in Live API sessions to match tool call responses to requests and to identify calls in cancellation messages.
final String? id;