FunctionResponse class

The result output from a function call.

Constructors

FunctionResponse({String? id, required String name, required Map<String, dynamic> response, List<FunctionResponseInlinePart>? parts, bool? willContinue, FunctionResponseScheduling? scheduling})
Creates a FunctionResponse.
const
FunctionResponse.fromJson(Map<String, dynamic> json)
Creates a FunctionResponse from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
Optional ID of the function call this response is for.
final
name String
The name of the function that was called.
final
parts List<FunctionResponseInlinePart>?
Ordered parts that constitute the function response.
final
response Map<String, dynamic>
The function response.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduling → FunctionResponseScheduling?
Specifies how the response should be scheduled in the conversation.
final
willContinue bool?
Signals that function call continues as a generator.
final

Methods

copyWith({Object? id = unsetCopyWithValue, Object? name = unsetCopyWithValue, Object? response = unsetCopyWithValue, Object? parts = unsetCopyWithValue, Object? willContinue = unsetCopyWithValue, Object? scheduling = unsetCopyWithValue}) FunctionResponse
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited