id property

String? id
final

Optional ID of the function call this response is for.

Used in Live API sessions to correlate responses with the original function call requests. Should match the FunctionCall.id of the call being responded to.

Implementation

final String? id;