scheduling property
FunctionResponseScheduling?
scheduling
final
Specifies how the response should be scheduled in the conversation.
Implementation
final FunctionResponseScheduling? scheduling;
Specifies how the response should be scheduled in the conversation.
final FunctionResponseScheduling? scheduling;