TextPart class

Text content.

Constructors

TextPart(String text, {bool? thought, List<int>? thoughtSignature})
Creates a TextPart.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Plain text content.
final
thought bool?
Whether this text is a thought/reasoning step.
final
thoughtSignature List<int>?
Optional opaque thought signature bytes.
final

Methods

copyWith({Object? text = unsetCopyWithValue, Object? thought = unsetCopyWithValue, Object? thoughtSignature = unsetCopyWithValue}) TextPart
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited