Tool class
Tool that the model may use to generate a response.
For Live voice, only functionDeclarations are supported in this package.
Constructors
-
Tool({List<
FunctionDeclaration> ? functionDeclarations}) -
Creates a Tool with
functionDeclarationsonly.const -
Tool.fromJson(Map<
String, dynamic> json) -
Creates a Tool from JSON.
factory
Properties
-
functionDeclarations
→ List<
FunctionDeclaration> ? -
List of function declarations.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? functionDeclarations = unsetCopyWithValue}) → Tool - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited